@@ -59,7 +59,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(subsets);
-$VERSION = '1.002';
+$VERSION = '1.004'; # Saturday 21 March 2009
 
 =head1 Description
 
@@ -69,7 +69,7 @@ standard Perl metaphor.
 C<subsets()> returns the number of subsets. Please note that this
 incloudes the empty set as it is a subset of all sets.
 
-Its easy to use and fast. Its written in 100% Pure Perl.
+C<subsets()> is easy to use and fast. It is written in 100% Pure Perl.
 
 Please note that the order in which the subsets are generated is
 not guaranteed, so please do not rely on it.
@@ -103,8 +103,16 @@ http://www.handybackup.com
 
 =head1 See Also
 
-L<Math::Permute::List>
-L<Math::Disarrange::List>
+
+=over
+
+=item L<Math::Cartesian::List>
+
+=item L<Math::Disarrange::List>
+
+=item L<Math::Permute::List>
+
+=back
 
 =head1 Copyright
 
